Options for summary statistics

stats_summ_options(
  ...,
  rounding = 3,
  acc_error_abs = NULL,
  acc_error_rel = NULL,
  bootstrap = bootstrap_options()
)

Arguments

...

These dots are reserved for future extensibility and must be empty.

rounding

number of decimals to round to.

acc_error_abs, acc_error_rel

For calculating accuracy(): Positive number providing an absolute or relative error margin. The cutoff is exclusive of the error margin. When NULL (the default), accuracy will not be calculated and will return NA instead.

bootstrap

Options for bootstrapping confidence intervals around the summary statistics. This must be the result from a call to bootstrap_options().

Value

A list.