calculate_bayesian_impact.RdBayesian impact (BI), as defined here, is the gain in accuracy that is obtained when using Bayesian updating, compared to using a priori (population) parameter estimates. The BI is computed based on accuracy measures (RMSE and MAPE), but not on bias estimates (MPE).
calculate_bayesian_impact(.res)output object (mipdeval_results) from run_eval(), or
data.frame with raw results.
a tibble with bayesian impact values, based on RMSE and MAPE