Calculate the impact of using Bayesian updating compared to population estimates
Source:R/calculate_bayesian_impact.R
calculate_bayesian_impact.RdBayesian impact (BI), as defined here, is the gain in accuracy that is obtained when using Bayesian updating, compared to using a priori (population) parameter estimates. The BI is computed based on accuracy measures (RMSE and MAPE), but not on bias estimates (MPE).
Arguments
- .res
output object (
mipdeval_results) fromrun_eval(), ordata.framewith raw results.