handle_covariate_censoring.Rd
This removes new covariate information after a certain time cutoff
handle_covariate_censoring(covariates, t, censor = TRUE)
covariates data for single subject
timepoint cutoff at which covariate are to be censored (if censor=FALSE)
censor=FALSE
censor covariate data?
list with similar shape as covariates object, just with potentially censored future data.
covariates