parse_psn_proseval_results.Rd
Parse PsN::proseval results.csv to filter out only the rows that we need (for prediction of next sample or group of samples)
parse_psn_proseval_results(data, group = NULL)
results data.frame or path to csv file
optional. Group samples using the column name specified in group
group
A data.frame